body {
    background-color: #555;
    color: white;
    font-family: monospace;
}

.demo-class {
    background-color: yellowgreen;
    color: black;
    padding: 10px;
    margin: 10px;
    border-radius: 5px;
}

.centered {
    text-align: center;
}
